Django SEO
==========

Put short description here...

.. image:: https://travis-ci.org/bashu/django-easy-seo.svg?branch=develop
   :target: https://travis-ci.org/bashu/django-easy-seo
   :alt: Build Status

.. image:: https://badge.fury.io/py/django-easy-seo.png
   :target: http://badge.fury.io/py/django-easy-seo
   :alt: Latest Release

.. image:: https://pypip.in/d/django-easy-seo/badge.png
   :target: https://crate.io/packages/django-easy-seo?version=latest
   :alt: Downloads
